var config = require('../../config');
let app = getApp();
Page({
  data: {
    userAuth: false, // 用户信息授权（为了拿unionId）
    stepAuth: false, // 步数授权
    // commitStepPopupShow: false, // 同步步数成功弹窗
    activityExplainShow: false, // 活动说明弹窗
    currentSteps: 0,
    targetSteps: 0,
    stepRecordList: [],
    showGetUserInfo: false,
    isFirstReq: true
  },
  
  onShow() {
    this.getPageData();
  },

  getPageData() {
    // 1、第一步，先判断用户信息和步数是否授过权
    wx.getSetting({
      success:(res) => {
        // 用户信息是否授权
        if (res.authSetting['scope.userInfo']) {
          app.globalData.userAuth = true;
        }
        // 微信步数是否授权
        if (res.authSetting['scope.werun']) {
          app.globalData.stepAuth = true;
        }
        // 2、询问后端是否需要unionId授权
        this.needUnionAuth().then(unionRes => {
          app.globalData.unionAuth = unionRes;
          console.log('needUnionAuth',app.globalData.unionAuth,app.globalData.userAuth,app.globalData.stepAuth)
          // 视图层数据赋值
          this.setData({
            userAuth: app.globalData.userAuth,
            stepAuth: app.globalData.stepAuth
          });
          if (app.globalData.unionAuth && app.globalData.stepAuth) {
            this.getClickStepData();
          } else if (app.globalData.stepAuth) {
            this.loadStepData();
          }
        });
      }
    });
  },

  // 询问后端是否需要unionId授权
  needUnionAuth() {
    return new Promise((resolve, reject) => {
      wx.login({
        success:wxres => {
          if (wxres.code) {
            wx.request({
              url: config.service.hostUrl + "/v1/auth_login",
              data: {
                js_code: wxres.code
              },
              method: 'POST',
              success:myres => {
                if (myres.data.code === 0) {
                  app.globalData.userInfo = myres.data.data;
                  app.globalData.token = myres.data.data.token;
                  resolve(true);
                } else if (myres.data.data.code === 401) {
                  resolve(false);
                }
              }
            });
          }
        }
      });
    });
  },

  // 页面加载时请求的展示步数数据
  loadStepData() {
    console.log('loadStepData')
    wx.getWeRunData({
      success:(stepres) => {
        wx.login({
          success:wxres => {
            if (wxres.code) {
              wx.request({
                url: config.service.hostUrl + "/v1/get_step_num",
                data: {
                  js_code: wxres.code,
                  encrypted_data: stepres.encryptedData,
                  iv: stepres.iv
                },
                method: 'POST',
                success:(res) => {
                  const resData = res.data.data;
                  this.setData({
                    currentSteps: (resData && resData[0]) ? resData[0].step : 0,
                    stepRecordList: resData
                  });
                  wx.setStorageSync('getStepLoading', Date.now());
                  wx.showModal({
                    content: '获取微信运动步数成功',
                    showCancel: false
                  });
                }
              });
            }
          }
        });
      }
    });
  },

  // 用户点击提交步数打卡1（处理授权情况）
  clickStepData(resCheck = false) {
    console.log('clickStepData')
    if (!resCheck && !this.data.isFirstReq && wx.getStorageSync('getStepLoading') && Date.now() - wx.getStorageSync('getStepLoading') < 60000) {
      wx.showToast({
        title: '已是最新步数，建议前往微信运动获取最新步数再返回同步',
        icon: 'none',
        duration: 2000
      });
      return;
    }
    let needStepAuth = (resCheck) => {
      wx.authorize({ // 调起授权窗口
        scope: 'scope.werun',
        success:() => { // 授权成功
          app.globalData.stepAuth = true;
          if (resCheck) this.clickStepData(true);
          else this.getClickStepData();
        },
        fail:(err) => { // 授权失败，因为用户拒绝或者用户曾经拒绝过，而且在这里不能直接去到openSetting页，需要通过一个弹窗中转过去
          this.authorizationFail();
        }
      });
    }
    if (app.globalData.unionAuth) { // 不需要unionId授权
      if (app.globalData.stepAuth) { // 步数已授权
        this.getClickStepData();
      } else { // 步数没有授权，弹出步数授权框
        needStepAuth();
      }
    } else { // 需要unionId授权
      if (!app.globalData.userAuth && !app.globalData.stepAuth) {
        wx.navigateTo({
          url: '/pages/authorization/authorization'
        });
      } else if (!app.globalData.userAuth && app.globalData.stepAuth) {
        this.showUserInfoPopup();
      } else if (app.globalData.userAuth && !app.globalData.stepAuth) {
        needStepAuth(true);
      } else if (app.globalData.userAuth && app.globalData.stepAuth) {
        wx.getUserInfo({
          withCredentials: true,
          success:(userres) => {
            this.sendUserInfo(userres.encryptedData, userres.iv);
          }
        });
      }
    }
  },

  // 用户点击提交步数打卡2（处理获步数和提交）
  getClickStepData() {
    console.log('getClickStepData')
    wx.getWeRunData({
      success:(stepres) => {
        wx.request({
          url: config.service.hostUrl + "/v1/sync_step_data",
          data: {
            encrypted_data: stepres.encryptedData,
            iv: stepres.iv
          },
          header: {
            'Authorization': app.globalData.token
          },
          method: 'POST',
          success:(res) => {
            this.data.isFirstReq = false;
            const resData = res.data.data;
            // 数据处理，结合两个数组判断是否显示打卡角标和状态
            const joinDate = [];
            resData.records_info.forEach(item => {
              joinDate.push(item.period);
            });
            resData.step_data.forEach(item => {
              if (joinDate.indexOf(item.period) > -1) {
                if (resData.records_info[joinDate.indexOf(item.period)].daka_done) {
                  item.status = 1; // 打卡成功
                } else {
                  item.status = 2; // 打卡失败
                }
              } else {
                item.status = 0; // 未参与打卡
              }
            });
            console.log(resData.step_data)
            this.setData({
              currentSteps: (resData.step_data && resData.step_data[0]) ? resData.step_data[0].step : 0,
              targetSteps: resData.total_step,
              stepRecordList: resData.step_data
            });
            wx.setStorageSync('getStepLoading', Date.now());
            wx.showModal({
              content: '获取微信运动步数成功',
              showCancel: false
            });
          }
        });
      },
      fail:(err) => {
        this.authorizationFail();
      }
    });
  },

  // 显示隐藏用户信息授权弹框
  showUserInfoPopup() {
    this.setData({
      showGetUserInfo: !this.data.showGetUserInfo
    });
  },

  // 用户同意授权
  onGotUserInfo(event) {
    console.log('onGotUserInfo')
    app.globalData.userAuth = true;
    this.setData({
      showGetUserInfo: !this.data.showGetUserInfo,
      userAuth: true
    });
    this.sendUserInfo(event.detail.encryptedData, event.detail.iv);
  },

  // 把用户授权信息传给后端,然后同步数据
  sendUserInfo(encryptedData, iv) {
    console.log('sendUserInfo',encryptedData, iv)
    wx.login({
      success:wxres => {
        if (wxres.code) {
          wx.request({
            url: config.service.hostUrl + "/v1/auth_login",
            data: {
              js_code: wxres.code,
              encrypted_data: encryptedData,
              iv: iv
            },
            method: 'POST',
            success:myres => {
              if (myres.data.code === 0) {
                app.globalData.unionAuth = true;
                app.globalData.userInfo = myres.data.data;
                app.globalData.token = myres.data.data.token;
                this.getClickStepData();
              }
            }
          });
        }
      }
    });
  },

  // 授权失败，去到openSetting页
  authorizationFail() {
    console.log('authorizationFail')
    wx.showModal({
      content: '如需完成步数打卡，请点击确定允许微信授权',
      success:(res) => {
        if (res.confirm) {
          wx.openSetting({
            success:(res) => {
              if (res.authSetting['scope.userInfo']) {
                app.globalData.userAuth = true;
                this.setData({
                  userAuth: true
                });
              } else {
                app.globalData.userAuth = false;
                this.setData({
                  userAuth: false
                });
              }
              if (res.authSetting['scope.werun']) {
                app.globalData.stepAuth = true;
                this.setData({
                  stepAuth: true
                });
              } else {
                app.globalData.stepAuth = false;
                this.setData({
                  stepAuth: false
                });
              }
            }
          });
        }
      }
    });
  },
  
  // 活动说明弹窗
  changeActivityExplainShow() {
    this.setData({
      activityExplainShow: !this.data.activityExplainShow
    });
  },


  // 暂留==================================================================

  // 通过code2session方式拿unionid
  // byCode2session() {
  //   wx.login({
  //     success:wxres => {
  //       if (wxres.code) {
  //         wx.request({
  //           url: 'https://api.weixin.qq.com/sns/jscode2session',
  //           data: {
  //             appid: 'wx035eac0d4d63b3e4',
  //             secret: 'cbb0d286083bee53e44f9518621eedb3',
  //             js_code: wxres.code,
  //             grant_type: 'authorization_code'
  //           },
  //           method: 'GET',
  //           success:res => {
  //             console.log('通过code2session方式拿unionid：',res.data.unionid)
  //           }
  //         });
  //       }
  //     }
  //   });
  // },

  // // 同步步数成功弹窗
  // changeShowPopup() {
  //   this.setData({
  //     commitStepPopupShow: !this.data.commitStepPopupShow
  //   });
  // },

  // goAuthorizationPage() {
  //   console.log(`/pages/authorization/authorization?userAuth=${this.data.userAuth}&stepAuth=${this.data.stepAuth}`)
  //   wx.navigateTo({
  //     url: `/pages/authorization/authorization?userAuth=${this.data.userAuth}&stepAuth=${this.data.stepAuth}`
  //   });
  // },

  // goCaptionPage() {
  //   wx.navigateTo({
  //     url: '/pages/caption/caption'
  //   });
  // },
})